@@ -1,6 +1,6 @@
 #!/bin/sh
 # This file is part of Firejail project
-# Copyright (C) 2014-2021 Firejail Authors
+# Copyright (C) 2014-2022 Firejail Authors
 # License GPL v2
 
 # Purpose: Fetch, compile, and install firejail from GitHub source. For
@@ -9,15 +9,13 @@ set -e
 
 git clone --depth=1 https://github.com/netblue30/firejail.git
 cd firejail
-./configure --enable-apparmor --prefix=/usr
+./configure
 
 # Fix https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=916920
-sed -i \
-    -e "s/# cgroup .*/cgroup no/" \
-    -e "s/# restricted-network .*/restricted-network yes/" \
+sed -i "s/# restricted-network .*/restricted-network yes/" \
     etc/firejail.config
 
-make deb
+make deb-apparmor
 sudo dpkg -i firejail*.deb
 echo "Firejail updated."
 cd ..
