@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2021 Firejail Authors
+ * Copyright (C) 2014-2022 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -68,8 +68,23 @@ static void process_file(const char *fname, const char *dir, void (*callback)(ch
 			ptr += 7;
 		else if (strncmp(ptr, "open ", 5) == 0)
 			ptr += 5;
+		else if (strncmp(ptr, "opendir ", 8) == 0)
+			ptr += 8;
+		else if (strncmp(ptr, "connect ", 8) == 0) {
+			ptr += 8;
+			// file descriptor argument
+			if (!isdigit(*ptr))
+				continue;
+			while (isdigit(*ptr))
+				ptr++;
+			if (*ptr++ != ' ')
+				continue;
+			if (*ptr != '/')
+				continue;
+		}
 		else
 			continue;
+
 		if (strncmp(ptr, dir, dir_len) != 0)
 			continue;
 
@@ -117,8 +132,19 @@ static void etc_callback(char *ptr) {
 	if (strncmp(ptr, "/etc/firejail", 13) == 0)
 		return;
 
+	// extract the directory:
+	assert(strncmp(ptr, "/etc", 4) == 0);
+	ptr += 4;
+	if (*ptr != '/')
+		return;
+	ptr++;
+
+	if (*ptr == '/')	// double '/'
+		ptr++;
+	if (*ptr == '\0')
+		return;
+
 	// add only top files and directories
-	ptr += 5;	// skip "/etc/"
 	char *end = strchr(ptr, '/');
 	if (end)
 		*end = '\0';
@@ -163,6 +189,11 @@ static char *var_skip[] = {
 static FileDB *var_out = NULL;
 static FileDB *var_skip = NULL;
 static void var_callback(char *ptr) {
+	// skip /var/lib/flatpak, /var/lib/snapd directory
+	if (strncmp(ptr, "/var/lib/flatpak", 16) == 0 ||
+	    strncmp(ptr, "/var/lib/snapd", 14) == 0)
+		return;
+
 	// extract the directory:
 	assert(strncmp(ptr, "/var", 4) == 0);
 	char *p1 = ptr + 4;
@@ -191,6 +222,88 @@ void build_var(const char *fname, FILE *fp) {
 	fprintf(fp, "include whitelist-var-common.inc\n");
 }
 
+//*******************************************
+// run directory
+//*******************************************
+static FileDB *run_out = NULL;
+static FileDB *run_skip = NULL;
+static void run_callback(char *ptr) {
+	// skip /run/firejail
+	if (strncmp(ptr, "/run/firejail", 13) == 0)
+		return;
+	// skip files in /run/user
+	if (strncmp(ptr, "/run/user", 9) == 0)
+		return;
+
+	// extract the directory:
+	assert(strncmp(ptr, "/run", 4) == 0);
+	char *p1 = ptr + 4;
+	if (*p1 != '/')
+		return;
+	p1++;
+
+	if (*p1 == '/')	// double '/'
+		p1++;
+	if (*p1 == '\0')
+		return;
+
+	if (!filedb_find(run_skip, p1))
+		run_out = filedb_add(run_out, p1);
+}
+
+void build_run(const char *fname, FILE *fp) {
+	assert(fname);
+
+	run_skip = filedb_load_whitelist(run_skip, "whitelist-run-common.inc", "whitelist /run/");
+	process_files(fname, "/run", run_callback);
+
+	// always whitelist /run
+	if (run_out)
+		filedb_print(run_out, "whitelist /run/", fp);
+	fprintf(fp, "include whitelist-run-common.inc\n");
+}
+
+//*******************************************
+// ${RUNUSER} directory
+//*******************************************
+static char *runuser_fname = NULL;
+static FileDB *runuser_out = NULL;
+static FileDB *runuser_skip = NULL;
+static void runuser_callback(char *ptr) {
+	// extract the directory:
+	assert(runuser_fname);
+	assert(strncmp(ptr, runuser_fname, strlen(runuser_fname)) == 0);
+	char *p1 = ptr + strlen(runuser_fname);
+	if (*p1 != '/')
+		return;
+	p1++;
+
+	if (*p1 == '/')	// double '/'
+		p1++;
+	if (*p1 == '\0')
+		return;
+
+	if (!filedb_find(runuser_skip, p1))
+		runuser_out = filedb_add(runuser_out, p1);
+}
+
+void build_runuser(const char *fname, FILE *fp) {
+	assert(fname);
+
+	if (asprintf(&runuser_fname, "/run/user/%d", getuid()) < 0)
+		errExit("asprintf");
+
+	if (!is_dir(runuser_fname))
+		return;
+
+	runuser_skip = filedb_load_whitelist(runuser_skip, "whitelist-runuser-common.inc", "whitelist ${RUNUSER}/");
+	process_files(fname, runuser_fname, runuser_callback);
+
+	// always whitelist /run/user/$UID
+	if (runuser_out)
+		filedb_print(runuser_out, "whitelist ${RUNUSER}/", fp);
+	fprintf(fp, "include whitelist-runuser-common.inc\n");
+}
 
 //*******************************************
 // usr/share directory
@@ -236,9 +349,6 @@ void build_share(const char *fname, FILE *fp) {
 //*******************************************
 static FileDB *tmp_out = NULL;
 static void tmp_callback(char *ptr) {
-	// skip strace file
-	if (strncmp(ptr, "/tmp/firejail-strace", 20) == 0)
-		return;
 	if (strncmp(ptr, "/tmp/runtime-", 13) == 0)
 		return;
 	if (strcmp(ptr, "/tmp") == 0)
@@ -289,6 +399,7 @@ static char *dev_skip[] = {
 	"/dev/pts",
 	"/dev/ptmx",
 	"/dev/log",
+	"/dev/shm",
 
 	"/dev/aload",	// old ALSA devices, not covered in private-dev
 	"/dev/dsp",		// old OSS device, deprecated
