@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2021 Firejail Authors
+ * Copyright (C) 2014-2022 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -20,6 +20,7 @@
 
 #include "fbuilder.h"
 
+#if 0
 void build_seccomp(const char *fname, FILE *fp) {
 	assert(fname);
 	assert(fp);
@@ -78,6 +79,7 @@ void build_seccomp(const char *fname, FILE *fp) {
 
 	fclose(fp2);
 }
+#endif
 
 //***************************************
 // protocol
@@ -188,7 +190,7 @@ void build_protocol(const char *fname, FILE *fp) {
 	if (net == 0)
 		fprintf(fp, "net none\n");
 	else {
-		fprintf(fp, "# net eth0\n");
+		fprintf(fp, "#net eth0\n");
 		fprintf(fp, "netfilter\n");
 	}
 }
