@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2021 Firejail Authors
+ * Copyright (C) 2014-2022 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -88,7 +88,8 @@ static void selinux_relabel_path(const char *path, const char *inside_path) {
 		if (arg_debug)
 			printf("Relabeling %s as %s (%s)\n", path, inside_path, fcon);
 
-		setfilecon_raw(procfs_path, fcon);
+		if (setfilecon_raw(procfs_path, fcon) != 0 && arg_debug)
+			printf("Cannot relabel %s: %s\n", path, strerror(errno));
 	}
 	freecon(fcon);
  close:
@@ -199,7 +200,8 @@ static char *proc_pid_to_self(const char *target) {
 
 	// check where /proc/self points to
 	static const char proc_self[] = "/proc/self";
-	if (!(proc_pid = realpath(proc_self, NULL)))
+	proc_pid = realpath(proc_self, NULL);
+	if (proc_pid == NULL)
 		goto done;
 
 	// redirect /proc/PID/xxx -> /proc/self/XXX
@@ -284,11 +286,9 @@ static int fs_copydir(const char *infname, const struct stat *st, int ftype, str
 	}
 
 	// extract mode and ownership
-	if (stat(infname, &s) != 0) {
-		if (!arg_quiet)
-			fprintf(stderr, "Warning fcopy: skipping %s, cannot find inode\n", infname);
+	if (stat(infname, &s) != 0)
 		goto out;
-	}
+
 	uid_t uid = s.st_uid;
 	gid_t gid = s.st_gid;
 	mode_t mode = s.st_mode;
@@ -470,18 +470,12 @@ int main(int argc, char **argv) {
 	size_t len = strlen(src);
 	while (len > 1 && src[len - 1] == '/')
 		src[--len] = '\0';
-	if (strcspn(src, "\\*&!?\"'<>%^(){}[];,") != len) {
-		fprintf(stderr, "Error fcopy: invalid source file name %s\n", src);
-		exit(1);
-	}
+	reject_meta_chars(src, 0);
 
 	len = strlen(dest);
 	while (len > 1 && dest[len - 1] == '/')
 		dest[--len] = '\0';
-	if (strcspn(dest, "\\*&!?\"'<>%^(){}[];,~") != len) {
-		fprintf(stderr, "Error fcopy: invalid dest file name %s\n", dest);
-		exit(1);
-	}
+	reject_meta_chars(dest, 0);
 
 	// the destination should be a directory;
 	struct stat s;
