@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2021 Firejail Authors
+ * Copyright (C) 2014-2022 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -22,6 +22,7 @@
 #include "../include/firejail_user.h"
 int arg_debug = 0;
 char *arg_bindir = "/usr/local/bin";
+int arg_guide = 0;
 
 static char *usage_str =
 	"Firecfg is the desktop configuration utility for Firejail software. The utility\n"
@@ -37,6 +38,7 @@ static char *usage_str =
 	"   --debug - print debug messages.\n\n"
 	"   --fix - fix .desktop files.\n\n"
 	"   --fix-sound - create ~/.config/pulse/client.conf file.\n\n"
+	"   --guide - guided configuration for new users.\n\n"
 	"   --help, -? - this help screen.\n\n"
 	"   --list - list all firejail symbolic links.\n\n"
 	"   --version - print program version and exit.\n\n"
@@ -171,17 +173,17 @@ static void set_file(const char *name, const char *firejail_exec) {
 	free(fname);
 }
 
-// parse /usr/lib/firejail/firecfg.cfg file
+// parse /etc/firejail/firecfg.config file
 static void set_links_firecfg(void) {
 	char *cfgfile;
-	if (asprintf(&cfgfile, "%s/firejail/firecfg.config", LIBDIR) == -1)
+	if (asprintf(&cfgfile, "%s/firecfg.config", SYSCONFDIR) == -1)
 		errExit("asprintf");
 
 	char *firejail_exec;
 	if (asprintf(&firejail_exec, "%s/bin/firejail", PREFIX) == -1)
 		errExit("asprintf");
 
-	// parse /usr/lib/firejail/firecfg.cfg file
+	// parse /etc/firejail/firecfg.config file
 	FILE *fp = fopen(cfgfile, "r");
 	if (!fp) {
 		perror("fopen");
@@ -373,6 +375,9 @@ int main(int argc, char **argv) {
 			fix_desktop_files(home);
 			return 0;
 		}
+		else if (strcmp(argv[i], "--guide") == 0) {
+			arg_guide = 1;
+		}
 		else if (strcmp(argv[i], "--list") == 0) {
 			list();
 			return 0;
@@ -437,10 +442,33 @@ int main(int argc, char **argv) {
 		umask(orig_umask);
 	}
 
+	if (arg_guide) {
+		char *cmd;
+if (arg_debug) {
+		if (asprintf(&cmd, "sudo %s/firejail/firejail-welcome.sh /usr/lib/firejail/fzenity %s %s", LIBDIR, SYSCONFDIR, user) == -1)
+			errExit("asprintf");
+}
+else {
+		if (asprintf(&cmd, "sudo %s/firejail/firejail-welcome.sh /usr/bin/zenity %s %s", LIBDIR, SYSCONFDIR, user) == -1)
+			errExit("asprintf");
+}
+		int status = system(cmd);
+		if (status == -1) {
+			fprintf(stderr, "Error: cannot run firejail-welcome.sh\n");
+			exit(1);
+		}
+		free(cmd);
+
+		// the last 8 bits of the status is the return value of the command executed by system()
+		// firejail-welcome.sh returns 55 if setting sysmlinks is required
+		if (WEXITSTATUS(status)  != 55)
+			return 0;
+	}
+
 	// clear all symlinks
 	clean();
 
-	// set new symlinks based on /usr/lib/firejail/firecfg.cfg
+	// set new symlinks based on /etc/firejail/firecfg.config
 	set_links_firecfg();
 
 	if (getuid() == 0) {
@@ -468,8 +496,6 @@ int main(int argc, char **argv) {
 #endif
 	}
 
-
-
 	// set new symlinks based on ~/.config/firejail directory
 	set_links_homedir(home);
 
