@@ -22,7 +22,6 @@
 #include "firejail.h"
 #include "../include/gcov_wrapper.h"
 #include <sys/mount.h>
-#include <sys/sendfile.h>
 #include <errno.h>
 
 #include <fcntl.h>
@@ -34,41 +33,27 @@
 void fs_check_chroot_dir(void) {
 	EUID_ASSERT();
 	assert(cfg.chrootdir);
-	if (strstr(cfg.chrootdir, "..") ||
-	    is_link(cfg.chrootdir))
-		goto errout;
 
 	// check chroot dirname exists, chrooting into the root directory is not allowed
 	char *rpath = realpath(cfg.chrootdir, NULL);
-	if (rpath == NULL || !is_dir(rpath) || strcmp(rpath, "/") == 0)
-		goto errout;
-
-	char *overlay;
-	if (asprintf(&overlay, "%s/.firejail", cfg.homedir) == -1)
-		errExit("asprintf");
-	if (strncmp(rpath, overlay, strlen(overlay)) == 0) {
-		fprintf(stderr, "Error: invalid chroot directory: no directories in %s are allowed\n", overlay);
+	if (rpath == NULL || !is_dir(rpath) || strcmp(rpath, "/") == 0) {
+		fprintf(stderr, "Error: invalid chroot directory %s\n", cfg.chrootdir);
 		exit(1);
 	}
-	free(overlay);
 
 	cfg.chrootdir = rpath;
 	return;
-
-errout:
-	fprintf(stderr, "Error: invalid chroot directory %s\n", cfg.chrootdir);
-	exit(1);
 }
 
 // copy /etc/resolv.conf or /etc/machine-id in chroot directory
 static void update_file(int parentfd, const char *relpath) {
 	assert(relpath && relpath[0] && relpath[0] != '/');
 
-	char *abspath;
-	if (asprintf(&abspath, "/%s", relpath) == -1)
-		errExit("asprintf");
-	int in = open(abspath, O_RDONLY|O_CLOEXEC);
-	free(abspath);
+	int rootfd = open("/", O_PATH|O_CLOEXEC);
+	if (rootfd == -1)
+		errExit("open");
+	int in = openat(rootfd, relpath, O_RDONLY|O_CLOEXEC);
+	close(rootfd);
 	if (in == -1)
 		goto errout;
 
@@ -91,8 +76,8 @@ static void update_file(int parentfd, const char *relpath) {
 		close(in);
 		goto errout;
 	}
-	if (sendfile(out, in, NULL, src.st_size) == -1)
-		errExit("sendfile");
+	if (copy_file_by_fd(in, out) != 0)
+		errExit("copy_file_by_fd");
 	close(in);
 	close(out);
 	return;
@@ -134,6 +119,11 @@ void fs_chroot(const char *rootdir) {
 	int parentfd = safer_openat(-1, rootdir, O_PATH|O_DIRECTORY|O_NOFOLLOW|O_CLOEXEC);
 	if (parentfd == -1)
 		errExit("safer_openat");
+
+	if (faccessat(parentfd, ".", X_OK, 0) != 0) {
+		fprintf(stderr, "Error: no search permission on chroot directory\n");
+		exit(1);
+	}
 	// rootdir has to be owned by root and is not allowed to be generally writable,
 	// this also excludes /tmp and friends
 	struct stat s;
