@@ -162,7 +162,7 @@ static void disable_file(OPERATION op, const char *filename) {
 				fs_logger2("blacklist-nolog", fname);
 
 			// files in /etc will be reprocessed during /etc rebuild
-			if (strncmp(fname, "/etc/", 5) == 0) {
+			if (checkcfg(CFG_ETC_HIDE_BLACKLISTED) && strncmp(fname, "/etc/", 5) == 0) {
 				ProfileEntry *prf = malloc(sizeof(ProfileEntry));
 				if (!prf)
 					errExit("malloc");
@@ -530,7 +530,9 @@ static void fs_remount_simple(const char *path, OPERATION op) {
 	if (fstat(fd, &s) < 0) {
 		// fstat can fail with EACCES if path is a FUSE mount,
 		// mounted without 'allow_root' or 'allow_other'
-		if (errno != EACCES)
+		// fstat can also fail with EIO if the underlying FUSE system
+		// is being buggy
+		if (errno != EACCES && errno != EIO)
 			errExit("fstat");
 		close(fd);
 		goto out;
