@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2021 Firejail Authors
+ * Copyright (C) 2014-2022 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -20,25 +20,31 @@
 #include "firejail.h"
 #include <sys/mount.h>
 #include <sys/stat.h>
-#include <linux/limits.h>
 #include <glob.h>
 #include <dirent.h>
 #include <fcntl.h>
 #include <pwd.h>
 
-void fs_trace_preload(void) {
+// create an empty /etc/ld.so.preload
+void fs_trace_touch_preload(void) {
+	create_empty_file_as_root("/etc/ld.so.preload", S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
+}
+
+void fs_trace_touch_or_store_preload(void) {
 	struct stat s;
 
-	// create an empty /etc/ld.so.preload
-	if (stat("/etc/ld.so.preload", &s)) {
-		if (arg_debug)
-			printf("Creating an empty /etc/ld.so.preload file\n");
-		FILE *fp = fopen("/etc/ld.so.preload", "wxe");
-		if (!fp)
-			errExit("fopen");
-		SET_PERMS_STREAM(fp, 0, 0, S_IRUSR | S_IWRITE | S_IRGRP | S_IROTH);
-		fclose(fp);
-		fs_logger("touch /etc/ld.so.preload");
+	if (stat("/etc/ld.so.preload", &s) != 0) {
+		fs_trace_touch_preload();
+		return;
+	}
+
+	if (s.st_size == 0)
+		return;
+
+	// create a copy of /etc/ld.so.preload
+	if (copy_file("/etc/ld.so.preload", RUN_LDPRELOAD_FILE, 0, 0, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)) {
+		fprintf(stderr, "Error: cannot copy /etc/ld.so.preload file\n");
+		exit(1);
 	}
 }
 
@@ -47,7 +53,7 @@ void fs_tracefile(void) {
 	if (arg_debug)
 		printf("Creating an empty trace log file: %s\n", arg_tracefile);
 	EUID_USER();
-	int fd = open(arg_tracefile, O_CREAT|O_WRONLY|O_CLOEXEC, S_IRUSR | S_IWRITE | S_IRGRP | S_IROTH);
+	int fd = open(arg_tracefile, O_CREAT|O_WRONLY|O_CLOEXEC, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
 	if (fd == -1) {
 		perror("open");
 		fprintf(stderr, "Error: cannot open trace log file %s for writing\n", arg_tracefile);
@@ -83,7 +89,7 @@ void fs_trace(void) {
 	if (arg_debug)
 		printf("Create the new ld.so.preload file\n");
 
-	FILE *fp = fopen(RUN_LDPRELOAD_FILE, "we");
+	FILE *fp = fopen(RUN_LDPRELOAD_FILE, "ae");
 	if (!fp)
 		errExit("fopen");
 	const char *prefix = RUN_FIREJAIL_LIB_DIR;
@@ -100,7 +106,7 @@ void fs_trace(void) {
 		fmessage("Post-exec seccomp protector enabled\n");
 	}
 
-	SET_PERMS_STREAM(fp, 0, 0, S_IRUSR | S_IWRITE | S_IRGRP | S_IROTH);
+	SET_PERMS_STREAM(fp, 0, 0, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
 	fclose(fp);
 
 	// mount the new preload file
