@@ -105,7 +105,6 @@ char *arg_netfilter_file = NULL;			// netfilter file
 char *arg_netfilter6_file = NULL;		// netfilter6 file
 char *arg_netns = NULL;			// "ip netns"-created network namespace to use
 int arg_doubledash = 0;			// double dash
-int arg_shell_none = 0;			// run the program directly without a shell
 int arg_private_dev = 0;			// private dev directory
 int arg_keep_dev_shm = 0;                       // preserve /dev/shm
 int arg_private_etc = 0;			// private etc directory
@@ -134,6 +133,8 @@ int arg_writable_run_user = 0;			// writable /run/user
 int arg_writable_var_log = 0;		// writable /var/log
 int arg_appimage = 0;				// appimage
 int arg_apparmor = 0;				// apparmor
+char *apparmor_profile = NULL;	// apparmor profile
+bool apparmor_replace = false;	// apparmor profile
 int arg_allow_debuggers = 0;			// allow debuggers
 int arg_x11_block = 0;				// block X11
 int arg_x11_xorg = 0;				// use X11 security extension
@@ -157,6 +158,8 @@ int arg_dbus_log_user = 0;
 int arg_dbus_log_system = 0;
 int arg_tab = 0;
 int login_shell = 0;
+int just_run_the_shell = 0;
+int arg_netlock = 0;
 
 int parent_to_child_fds[2];
 int child_to_parent_fds[2];
@@ -202,6 +205,7 @@ static void my_handler(int s) {
 			kill(child, SIGKILL);
 		waitpid(child, NULL, 0);
 	}
+	release_sandbox_lock();
 	myexit(128 + s);
 }
 
@@ -245,6 +249,9 @@ static void init_cfg(int argc, char **argv) {
 	cfg.username = strdup(pw->pw_name);
 	if (!cfg.username)
 		errExit("strdup");
+	cfg.usershell = strdup(pw->pw_shell);
+	if (!cfg.usershell)
+		errExit("strdup");
 
 	// check user database
 	if (!firejail_user_check(cfg.username)) {
@@ -338,7 +345,8 @@ errout:
 
 
 static void exit_err_feature(const char *feature) {
-	fprintf(stderr, "Error: %s feature is disabled in Firejail configuration file\n", feature);
+	fprintf(stderr, "Error: %s feature is disabled in Firejail configuration file %s\n",
+		feature, SYSCONFDIR "/firejail.config");
 	exit(1);
 }
 
@@ -413,7 +421,7 @@ static void run_cmd_and_exit(int i, int argc, char **argv) {
 				fprintf(stderr, "Error: --nettrace is only available to root user\n");
 				exit(1);
 			}
-			netfilter_trace(0);
+			netfilter_trace(0, LIBDIR "/firejail/fnettrace");
 		}
 		else
 			exit_err_feature("networking");
@@ -426,12 +434,92 @@ static void run_cmd_and_exit(int i, int argc, char **argv) {
 				exit(1);
 			}
 			pid_t pid = require_pid(argv[i] + 11);
-			netfilter_trace(pid);
+			netfilter_trace(pid, LIBDIR "/firejail/fnettrace");
 		}
 		else
 			exit_err_feature("networking");
 		exit(0);
 	}
+	else if (strcmp(argv[i], "--dnstrace") == 0) {
+		if (checkcfg(CFG_NETWORK)) {
+			if (getuid() != 0) {
+				fprintf(stderr, "Error: --dnstrace is only available to root user\n");
+				exit(1);
+			}
+			netfilter_trace(0, LIBDIR "/firejail/fnettrace-dns");
+		}
+		else
+			exit_err_feature("networking");
+		exit(0);
+	}
+	else if (strncmp(argv[i], "--dnstrace=", 11) == 0) {
+		if (checkcfg(CFG_NETWORK)) {
+			if (getuid() != 0) {
+				fprintf(stderr, "Error: --dnstrace is only available to root user\n");
+				exit(1);
+			}
+			pid_t pid = require_pid(argv[i] + 11);
+			netfilter_trace(pid, LIBDIR "/firejail/fnettrace-dns");
+		}
+		else
+			exit_err_feature("networking");
+		exit(0);
+	}
+	else if (strcmp(argv[i], "--snitrace") == 0) {
+		if (checkcfg(CFG_NETWORK)) {
+			if (getuid() != 0) {
+				fprintf(stderr, "Error: --snitrace is only available to root user\n");
+				exit(1);
+			}
+			netfilter_trace(0, LIBDIR "/firejail/fnettrace-sni");
+		}
+		else
+			exit_err_feature("networking");
+		exit(0);
+	}
+	else if (strncmp(argv[i], "--snitrace=", 11) == 0) {
+		if (checkcfg(CFG_NETWORK)) {
+			if (getuid() != 0) {
+				fprintf(stderr, "Error: --snitrace is only available to root user\n");
+				exit(1);
+			}
+			pid_t pid = require_pid(argv[i] + 11);
+			netfilter_trace(pid, LIBDIR "/firejail/fnettrace-sni");
+		}
+		else
+			exit_err_feature("networking");
+		exit(0);
+	}
+
+
+	else if (strcmp(argv[i], "--icmptrace") == 0) {
+		if (checkcfg(CFG_NETWORK)) {
+			if (getuid() != 0) {
+				fprintf(stderr, "Error: --icmptrace is only available to root user\n");
+				exit(1);
+			}
+			netfilter_trace(0, LIBDIR "/firejail/fnettrace-icmp");
+		}
+		else
+			exit_err_feature("networking");
+		exit(0);
+	}
+	else if (strncmp(argv[i], "--icmptrace=", 12) == 0) {
+		if (checkcfg(CFG_NETWORK)) {
+			if (getuid() != 0) {
+				fprintf(stderr, "Error: -icmptrace is only available to root user\n");
+				exit(1);
+			}
+			pid_t pid = require_pid(argv[i] + 12);
+			netfilter_trace(pid, LIBDIR "/firejail/fnettrace-icmp");
+		}
+		else
+			exit_err_feature("networking");
+		exit(0);
+	}
+
+
+
 	else if (strncmp(argv[i], "--bandwidth=", 12) == 0) {
 		if (checkcfg(CFG_NETWORK)) {
 			logargs(argc, argv);
@@ -642,8 +730,7 @@ static void run_cmd_and_exit(int i, int argc, char **argv) {
 #ifdef HAVE_NETWORK
 	else if (strcmp(argv[i], "--netstats") == 0) {
 		if (checkcfg(CFG_NETWORK)) {
-			struct stat s;
-			if (stat("/proc/sys/kernel/grsecurity", &s) == 0 || pid_hidepid())
+			if (pid_hidepid())
 				sbox_run(SBOX_ROOT | SBOX_CAPS_HIDEPID | SBOX_SECCOMP | SBOX_ALLOW_STDIN,
 					2, PATH_FIREMON, "--netstats");
 			else
@@ -792,16 +879,9 @@ static void run_cmd_and_exit(int i, int argc, char **argv) {
 		if (checkcfg(CFG_JOIN) || getuid() == 0) {
 			logargs(argc, argv);
 
-			if (arg_shell_none) {
-				if (argc <= (i+1)) {
-					fprintf(stderr, "Error: --shell=none set, but no command specified\n");
-					exit(1);
-				}
-				cfg.original_program_index = i + 1;
-			}
-
-			if (!cfg.shell && !arg_shell_none)
-				cfg.shell = guess_shell();
+			if (argc <= (i+1))
+				just_run_the_shell = 1;
+			cfg.original_program_index = i + 1;
 
 			// join sandbox by pid or by name
 			pid_t pid = require_pid(argv[i] + 7);
@@ -818,20 +898,13 @@ static void run_cmd_and_exit(int i, int argc, char **argv) {
 		if (checkcfg(CFG_JOIN) || getuid() == 0) {
 			logargs(argc, argv);
 
-			if (arg_shell_none) {
-				if (argc <= (i+1)) {
-					fprintf(stderr, "Error: --shell=none set, but no command specified\n");
-					exit(1);
-				}
-				cfg.original_program_index = i + 1;
-			}
+			if (argc <= (i+1))
+				just_run_the_shell = 1;
+			cfg.original_program_index = i + 1;
 
 			// try to join by name only
 			pid_t pid;
 			if (!read_pid(argv[i] + 16, &pid)) {
-				if (!cfg.shell && !arg_shell_none)
-					cfg.shell = guess_shell();
-
 				join(pid, argc, argv, i + 1);
 				exit(0);
 			}
@@ -850,8 +923,9 @@ static void run_cmd_and_exit(int i, int argc, char **argv) {
 				exit(1);
 			}
 
-			if (!cfg.shell && !arg_shell_none)
-				cfg.shell = guess_shell();
+			if (argc <= (i+1))
+				just_run_the_shell = 1;
+			cfg.original_program_index = i + 1;
 
 			// join sandbox by pid or by name
 			pid_t pid = require_pid(argv[i] + 15);
@@ -870,8 +944,9 @@ static void run_cmd_and_exit(int i, int argc, char **argv) {
 			exit(1);
 		}
 
-		if (!cfg.shell && !arg_shell_none)
-			cfg.shell = guess_shell();
+		if (argc <= (i+1))
+			just_run_the_shell = 1;
+		cfg.original_program_index = i + 1;
 
 		// join sandbox by pid or by name
 		pid_t pid = require_pid(argv[i] + 18);
@@ -889,40 +964,6 @@ static void run_cmd_and_exit(int i, int argc, char **argv) {
 
 }
 
-char *guess_shell(void) {
-	const char *shell;
-	char *retval;
-
-	shell = env_get("SHELL");
-	if (shell) {
-		invalid_filename(shell, 0); // no globbing
-		if (access(shell, X_OK) == 0 && !is_dir(shell) && strstr(shell, "..") == NULL &&
-		    strcmp(gnu_basename(shell), "firejail") != 0)
-			goto found;
-	}
-
-	// shells in order of preference
-	static const char * const shells[] = {"/bin/bash", "/bin/csh", "/usr/bin/zsh", "/bin/sh", "/bin/ash", NULL };
-
-	int i = 0;
-	while (shells[i] != NULL) {
-		// access call checks as real UID/GID, not as effective UID/GID
-		if (access(shells[i], X_OK) == 0) {
-			shell = shells[i];
-			goto found;
-		}
-		i++;
-	}
-
-	return NULL;
-
- found:
-	retval = strdup(shell);
-	if (!retval)
-		errExit("strdup");
-	return retval;
-}
-
 // return argument index
 static int check_arg(int argc, char **argv, const char *argument, int strict) {
 	int i;
@@ -1011,11 +1052,8 @@ int main(int argc, char **argv, char **envp) {
 	int prog_index = -1;			  // index in argv where the program command starts
 	int lockfd_network = -1;
 	int lockfd_directory = -1;
-	int lockfd_sandboxfile = -1;
-	int option_cgroup = 0;
 	int custom_profile = 0;	// custom profile loaded
 	int arg_caps_cmdline = 0; 	// caps requested on command line (used to break out of --chroot)
-	int arg_netlock = 0;
 	char **ptr;
 
 
@@ -1290,7 +1328,8 @@ int main(int argc, char **argv, char **envp) {
 	if (check_arg(argc, argv, "--appimage", 1))
 		arg_appimage = 1;
 
-	// check for force-nonewprivs in /etc/firejail/firejail.config file
+	// load configuration file /etc/firejail/firejail.config
+	// and check for force-nonewprivs
 	if (checkcfg(CFG_FORCE_NONEWPRIVS))
 		arg_nonewprivs = 1;
 
@@ -1337,8 +1376,18 @@ int main(int argc, char **argv, char **envp) {
 		// filtering
 		//*************************************
 #ifdef HAVE_APPARMOR
-		else if (strcmp(argv[i], "--apparmor") == 0)
+		else if (strcmp(argv[i], "--apparmor") == 0) {
 			arg_apparmor = 1;
+			apparmor_profile = "firejail-default";
+		}
+		else if (strncmp(argv[i], "--apparmor=", 11) == 0) {
+			arg_apparmor = 1;
+			apparmor_profile = argv[i] + 11;
+		}
+		else if (strncmp(argv[i], "--apparmor-replace", 18) == 0) {
+			arg_apparmor = 1;
+			apparmor_replace = true;
+		}
 #endif
 		else if (strncmp(argv[i], "--protocol=", 11) == 0) {
 			if (checkcfg(CFG_SECCOMP)) {
@@ -1450,6 +1499,20 @@ int main(int argc, char **argv, char **envp) {
 			else
 				exit_err_feature("seccomp");
 		}
+		else if (strcmp(argv[i], "--restrict-namespaces") == 0) {
+			if (checkcfg(CFG_SECCOMP))
+				profile_list_augment(&cfg.restrict_namespaces, "cgroup,ipc,net,mnt,pid,time,user,uts");
+			else
+				exit_err_feature("seccomp");
+		}
+		else if (strncmp(argv[i], "--restrict-namespaces=", 22) == 0) {
+			if (checkcfg(CFG_SECCOMP)) {
+				const char *add = argv[i] + 22;
+				profile_list_augment(&cfg.restrict_namespaces, add);
+			}
+			else
+				exit_err_feature("seccomp");
+		}
 		else if (strncmp(argv[i], "--seccomp-error-action=", 23) == 0) {
 			if (checkcfg(CFG_SECCOMP)) {
 				int config_seccomp_error_action = checkcfg(CFG_SECCOMP_ERROR_ACTION);
@@ -1518,8 +1581,12 @@ int main(int argc, char **argv, char **envp) {
 				arg_tracefile = tmp;
 			}
 		}
-		else if (strcmp(argv[i], "--tracelog") == 0)
-			arg_tracelog = 1;
+		else if (strcmp(argv[i], "--tracelog") == 0) {
+			if (checkcfg(CFG_TRACELOG))
+				arg_tracelog = 1;
+			else
+				exit_err_feature("tracelog");
+		}
 		else if (strncmp(argv[i], "--rlimit-cpu=", 13) == 0) {
 			check_unsigned(argv[i] + 13, "Error: invalid rlimit");
 			sscanf(argv[i] + 13, "%llu", &cfg.rlimit_cpu);
@@ -1566,23 +1633,6 @@ int main(int argc, char **argv, char **envp) {
 				cfg.nice = 0;
 			arg_nice = 1;
 		}
-		else if (strncmp(argv[i], "--cgroup=", 9) == 0) {
-			if (checkcfg(CFG_CGROUP)) {
-				if (option_cgroup) {
-					fprintf(stderr, "Error: only one cgroup can be defined\n");
-					exit(1);
-				}
-				cfg.cgroup = strdup(argv[i] + 9);
-				if (!cfg.cgroup)
-					errExit("strdup");
-
-				check_cgroup_file(cfg.cgroup);
-				set_cgroup(cfg.cgroup, getpid());
-				option_cgroup = 1;
-			}
-			else
-				exit_err_feature("cgroup");
-		}
 
 		//*************************************
 		// filesystem
@@ -1701,11 +1751,6 @@ int main(int argc, char **argv, char **envp) {
 					fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
 					exit(1);
 				}
-				struct stat s;
-				if (stat("/proc/sys/kernel/grsecurity", &s) == 0) {
-					fprintf(stderr, "Error: --overlay option is not available on Grsecurity systems\n");
-					exit(1);
-				}
 				arg_overlay = 1;
 				arg_overlay_keep = 1;
 
@@ -1729,11 +1774,6 @@ int main(int argc, char **argv, char **envp) {
 					fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
 					exit(1);
 				}
-				struct stat s;
-				if (stat("/proc/sys/kernel/grsecurity", &s) == 0) {
-					fprintf(stderr, "Error: --overlay option is not available on Grsecurity systems\n");
-					exit(1);
-				}
 				arg_overlay = 1;
 				arg_overlay_keep = 1;
 				arg_overlay_reuse = 1;
@@ -1765,11 +1805,6 @@ int main(int argc, char **argv, char **envp) {
 					fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
 					exit(1);
 				}
-				struct stat s;
-				if (stat("/proc/sys/kernel/grsecurity", &s) == 0) {
-					fprintf(stderr, "Error: --overlay option is not available on Grsecurity systems\n");
-					exit(1);
-				}
 				arg_overlay = 1;
 			}
 			else
@@ -1908,11 +1943,6 @@ int main(int argc, char **argv, char **envp) {
 					exit(1);
 				}
 
-				struct stat s;
-				if (stat("/proc/sys/kernel/grsecurity", &s) == 0) {
-					fprintf(stderr, "Error: --chroot option is not available on Grsecurity systems\n");
-					exit(1);
-				}
 				// extract chroot dirname
 				cfg.chrootdir = argv[i] + 9;
 				if (*cfg.chrootdir == '\0') {
@@ -2740,45 +2770,9 @@ int main(int argc, char **argv, char **envp) {
 		else if (strncmp(argv[i], "--oom=", 6) == 0) {
 			// already handled
 		}
-		else if (strcmp(argv[i], "--shell=none") == 0) {
-			arg_shell_none = 1;
-			if (cfg.shell) {
-				fprintf(stderr, "Error: a shell was already specified\n");
-				return 1;
-			}
-		}
 		else if (strncmp(argv[i], "--shell=", 8) == 0) {
-			if (arg_shell_none) {
-				fprintf(stderr, "Error: --shell=none was already specified.\n");
-				return 1;
-			}
-			invalid_filename(argv[i] + 8, 0); // no globbing
-
-			if (cfg.shell) {
-				fprintf(stderr, "Error: only one user shell can be specified\n");
-				return 1;
-			}
-			cfg.shell = argv[i] + 8;
-
-			if (is_dir(cfg.shell) || strstr(cfg.shell, "..")) {
-				fprintf(stderr, "Error: invalid shell\n");
-				exit(1);
-			}
-
-			// access call checks as real UID/GID, not as effective UID/GID
-			if(cfg.chrootdir) {
-				char *shellpath;
-				if (asprintf(&shellpath, "%s%s", cfg.chrootdir, cfg.shell) == -1)
-					errExit("asprintf");
-				if (access(shellpath, X_OK)) {
-					fprintf(stderr, "Error: cannot access shell file in chroot\n");
-					exit(1);
-				}
-				free(shellpath);
-			} else if (access(cfg.shell, X_OK)) {
-				fprintf(stderr, "Error: cannot access shell file\n");
-				exit(1);
-			}
+			fprintf(stderr, "Warning: --shell feature has been deprecated\n");
+			exit(1);
 		}
 		else if (strcmp(argv[i], "-c") == 0) {
 			arg_command = 1;
@@ -2840,9 +2834,6 @@ int main(int argc, char **argv, char **envp) {
 				cfg.command_name = strdup(argv[i]);
 				if (!cfg.command_name)
 					errExit("strdup");
-
-				// disable shell=* for appimages
-				arg_shell_none = 0;
 			}
 			else
 				extract_command_name(i, argv);
@@ -2869,11 +2860,6 @@ int main(int argc, char **argv, char **envp) {
 		}
 	}
 
-	// prog_index could still be -1 if no program was specified
-	if (prog_index == -1 && arg_shell_none) {
-		fprintf(stderr, "Error: shell=none configured, but no program specified\n");
-		exit(1);
-	}
 
 	// check trace configuration
 	if (arg_trace && arg_tracelog) {
@@ -2917,27 +2903,18 @@ int main(int argc, char **argv, char **envp) {
 		free(msg);
 	}
 
-	// guess shell if unspecified
-	if (!arg_shell_none && !cfg.shell) {
-		cfg.shell = guess_shell();
-		if (!cfg.shell) {
-			fprintf(stderr, "Error: unable to guess your shell, please set explicitly by using --shell option.\n");
-			exit(1);
-		}
-		if (arg_debug)
-			printf("Autoselecting %s as shell\n", cfg.shell);
-	}
-
 	// build the sandbox command
-	if (prog_index == -1 && cfg.shell) {
-		assert(cfg.command_line == NULL); // runs cfg.shell
+	if (prog_index == -1) {
+		just_run_the_shell = 1;
+
+		assert(cfg.command_line == NULL); // runs the user shell
 		if (arg_appimage) {
 			fprintf(stderr, "Error: no appimage archive specified\n");
 			exit(1);
 		}
 
-		cfg.window_title = cfg.shell;
-		cfg.command_name = cfg.shell;
+		cfg.window_title = cfg.usershell;
+		cfg.command_name = cfg.usershell;
 	}
 	else if (arg_appimage) {
 		if (arg_debug)
@@ -2961,11 +2938,8 @@ int main(int argc, char **argv, char **envp) {
 
 	// load the profile
 	if (!arg_noprofile && !custom_profile) {
-		if (arg_appimage) {
+		if (arg_appimage)
 			custom_profile = appimage_find_profile(cfg.command_name);
-			// disable shell=* for appimages
-			arg_shell_none = 0;
-		}
 		else
 			custom_profile = profile_find_firejail(cfg.command_name, 1);
 	}
@@ -3121,7 +3095,7 @@ int main(int argc, char **argv, char **envp) {
 	EUID_USER();
 
 	// sandbox pidfile
-	lockfd_sandboxfile = set_sandbox_run_file(getpid(), child);
+	set_sandbox_run_file(getpid(), child);
 
 	if (!arg_command && !arg_quiet) {
 		fmessage("Parent pid %u, child pid %u\n", sandbox_pid, child);
@@ -3317,7 +3291,7 @@ int main(int argc, char **argv, char **envp) {
 				errExit("setresuid");
 
 			char arg[64];
-			snprintf(arg, sizeof(arg), "--netlock=%d", getpid());
+			snprintf(arg, sizeof(arg), "--netlock=%d", sandbox_pid);
 
 			char *cmd[3];
 			cmd[0] = BINDIR "/firejail";
@@ -3346,8 +3320,7 @@ int main(int argc, char **argv, char **envp) {
 	// end of signal-safe code
 	//*****************************
 
-	// release lock
-	close(lockfd_sandboxfile);
+	release_sandbox_lock();
 
 	if (WIFEXITED(status)){
 		myexit(WEXITSTATUS(status));
