@@ -91,24 +91,20 @@ void netfilter_netlock(pid_t pid) {
 	// it will never get here!!
 }
 
-void netfilter_trace(pid_t pid) {
+void netfilter_trace(pid_t pid, const char *cmd) {
 	EUID_ASSERT();
 
 	// a pid of 0 means the main system network namespace
 	if (pid)
 		enter_network_namespace(pid);
 
-	char *cmd;
-	if (asprintf(&cmd, "%s/firejail/fnettrace", LIBDIR) == -1)
-		errExit("asprintf");
-
 	//************************
 	// build command
 	//************************
 	char *arg[4];
 	arg[0] = "/bin/sh";
 	arg[1] = "-c";
-	arg[2] = cmd;
+	arg[2] = (char *) cmd;
 	arg[3] = NULL;
 
 	clearenv();
