@@ -34,67 +34,28 @@ void preproc_build_firejail_dir(void) {
 		create_empty_dir_as_root(RUN_FIREJAIL_BASEDIR, 0755);
 	}
 
-	if (stat(RUN_FIREJAIL_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_DIR, 0755);
-	}
+	create_empty_dir_as_root(RUN_FIREJAIL_DIR, 0755);
+	create_empty_dir_as_root(RUN_FIREJAIL_NETWORK_DIR, 0755);
+	create_empty_dir_as_root(RUN_FIREJAIL_BANDWIDTH_DIR, 0755);
+	create_empty_dir_as_root(RUN_FIREJAIL_NAME_DIR, 0755);
+	create_empty_dir_as_root(RUN_FIREJAIL_PROFILE_DIR, 0755);
+	create_empty_dir_as_root(RUN_FIREJAIL_X11_DIR, 0755);
+	create_empty_dir_as_root(RUN_FIREJAIL_APPIMAGE_DIR, 0755);
+	create_empty_dir_as_root(RUN_FIREJAIL_LIB_DIR, 0755);
+	create_empty_dir_as_root(RUN_MNT_DIR, 0755);
 
 	// restricted search permission
 	// only root should be able to lock files in this directory
-	if (stat(RUN_FIREJAIL_SANDBOX_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_SANDBOX_DIR, 0700);
-	}
+	create_empty_dir_as_root(RUN_FIREJAIL_SANDBOX_DIR, 0700);
 
-	if (stat(RUN_FIREJAIL_NETWORK_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_NETWORK_DIR, 0755);
-	}
-
-	if (stat(RUN_FIREJAIL_BANDWIDTH_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_BANDWIDTH_DIR, 0755);
-	}
-
-	if (stat(RUN_FIREJAIL_NAME_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_NAME_DIR, 0755);
-	}
-
-	if (stat(RUN_FIREJAIL_PROFILE_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_PROFILE_DIR, 0755);
-	}
-
-	if (stat(RUN_FIREJAIL_X11_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_X11_DIR, 0755);
-	}
-
-	if (stat(RUN_FIREJAIL_DBUS_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_DBUS_DIR, 0755);
-		if (arg_debug)
-			printf("Remounting the " RUN_FIREJAIL_DBUS_DIR
-				   " directory as noexec\n");
-		if (mount(RUN_FIREJAIL_DBUS_DIR, RUN_FIREJAIL_DBUS_DIR, NULL,
-				  MS_BIND, NULL) == -1)
-			errExit("mounting " RUN_FIREJAIL_DBUS_DIR);
-		if (mount(NULL, RUN_FIREJAIL_DBUS_DIR, NULL,
-				  MS_REMOUNT | MS_BIND | MS_NOSUID | MS_NOEXEC | MS_NODEV,
-				  "mode=755,gid=0") == -1)
-			errExit("remounting " RUN_FIREJAIL_DBUS_DIR);
-	}
-
-	if (stat(RUN_FIREJAIL_APPIMAGE_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_APPIMAGE_DIR, 0755);
-	}
-
-	if (stat(RUN_FIREJAIL_LIB_DIR, &s)) {
-		create_empty_dir_as_root(RUN_FIREJAIL_LIB_DIR, 0755);
-	}
-
-	if (stat(RUN_MNT_DIR, &s)) {
-		create_empty_dir_as_root(RUN_MNT_DIR, 0755);
-	}
-
-	create_empty_file_as_root(RUN_RO_FILE, S_IRUSR);
-	fs_remount(RUN_RO_FILE, MOUNT_READONLY, 0);
+	create_empty_dir_as_root(RUN_FIREJAIL_DBUS_DIR, 0755);
+	fs_remount(RUN_FIREJAIL_DBUS_DIR, MOUNT_NOEXEC, 0);
 
 	create_empty_dir_as_root(RUN_RO_DIR, S_IRUSR);
 	fs_remount(RUN_RO_DIR, MOUNT_READONLY, 0);
+
+	create_empty_file_as_root(RUN_RO_FILE, S_IRUSR);
+	fs_remount(RUN_RO_FILE, MOUNT_READONLY, 0);
 }
 
 // build /run/firejail/mnt directory
@@ -130,10 +91,18 @@ void preproc_mount_mnt_dir(void) {
 			copy_file(PATH_SECCOMP_MDWX, RUN_SECCOMP_MDWX, getuid(), getgid(), 0644); // root needed
 			copy_file(PATH_SECCOMP_MDWX_32, RUN_SECCOMP_MDWX_32, getuid(), getgid(), 0644); // root needed
 		}
-		// as root, create empty RUN_SECCOMP_PROTOCOL and RUN_SECCOMP_POSTEXEC files
+		// as root, create empty RUN_SECCOMP_PROTOCOL, RUN_SECCOMP_NS and RUN_SECCOMP_POSTEXEC files
 		create_empty_file_as_root(RUN_SECCOMP_PROTOCOL, 0644);
 		if (set_perms(RUN_SECCOMP_PROTOCOL, getuid(), getgid(), 0644))
 			errExit("set_perms");
+		if (cfg.restrict_namespaces) {
+			create_empty_file_as_root(RUN_SECCOMP_NS, 0644);
+			if (set_perms(RUN_SECCOMP_NS, getuid(), getgid(), 0644))
+				errExit("set_perms");
+			create_empty_file_as_root(RUN_SECCOMP_NS_32, 0644);
+			if (set_perms(RUN_SECCOMP_NS_32, getuid(), getgid(), 0644))
+				errExit("set_perms");
+		}
 		create_empty_file_as_root(RUN_SECCOMP_POSTEXEC, 0644);
 		if (set_perms(RUN_SECCOMP_POSTEXEC, getuid(), getgid(), 0644))
 			errExit("set_perms");
