@@ -26,7 +26,8 @@
 
 extern char *xephyr_screen;
 
-#define MAX_READ 8192				  // line buffer for profile files
+#define MAX_READ 8192		// line buffer for profile files
+#define MAX_LIST 16384		// size limit for argument lists
 
 // find and read the profile specified by name from dir directory
 // return  1 if a profile was found
@@ -367,11 +368,13 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		return 0;
 	}
 	else if (strcmp(ptr, "shell none") == 0) {
-		arg_shell_none = 1;
+		fprintf(stderr, "Warning: \"shell none\" command in the profile file is done by default; the command will be deprecated\n");
 		return 0;
 	}
 	else if (strcmp(ptr, "tracelog") == 0) {
-		arg_tracelog = 1;
+		if (checkcfg(CFG_TRACELOG))
+			arg_tracelog = 1;
+		// no warning, we have tracelog in over 400 profiles
 		return 0;
 	}
 	else if (strcmp(ptr, "private") == 0) {
@@ -649,6 +652,16 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		}
 		else
 			warning_feature_disabled("networking");
+#endif
+		return 0;
+	}
+	else if (strcmp(ptr, "netlock") == 0) {
+#ifdef HAVE_NETWORK
+		if (checkcfg(CFG_NETWORK)) {
+			arg_netlock = 1;
+		}
+		else
+			warning_feature_disabled("networking");
 #endif
 		return 0;
 	}
@@ -938,6 +951,33 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 	if (strcmp(ptr, "apparmor") == 0) {
 #ifdef HAVE_APPARMOR
 		arg_apparmor = 1;
+		apparmor_profile = "firejail-default";
+#endif
+		return 0;
+	}
+
+	if (strncmp(ptr, "apparmor ", 9) == 0) {
+#ifdef HAVE_APPARMOR
+		arg_apparmor = 1;
+		apparmor_profile = strdup(ptr + 9);
+		if (!apparmor_profile)
+			errExit("strdup");
+#endif
+		return 0;
+	}
+
+	if (strcmp(ptr, "apparmor-replace") == 0) {
+#ifdef HAVE_APPARMOR
+		arg_apparmor = 1;
+		apparmor_replace = true;
+#endif
+		return 0;
+	}
+
+	if (strcmp(ptr, "apparmor-stack") == 0) {
+#ifdef HAVE_APPARMOR
+		arg_apparmor = 1;
+		apparmor_replace = false;
 #endif
 		return 0;
 	}
@@ -1042,6 +1082,24 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		return 0;
 	}
 
+	// restrict-namespaces
+	if (strcmp(ptr, "restrict-namespaces") == 0) {
+		if (checkcfg(CFG_SECCOMP))
+			profile_list_augment(&cfg.restrict_namespaces, "cgroup,ipc,net,mnt,pid,time,user,uts");
+		else
+			warning_feature_disabled("seccomp");
+		return 0;
+	}
+	if (strncmp(ptr, "restrict-namespaces ", 20) == 0) {
+		if (checkcfg(CFG_SECCOMP)) {
+			const char *add = ptr + 20;
+			profile_list_augment(&cfg.restrict_namespaces, add);
+		}
+		else
+			warning_feature_disabled("seccomp");
+		return 0;
+	}
+
 	// seccomp error action
 	if (strncmp(ptr, "seccomp-error-action ", 21) == 0) {
 		if (checkcfg(CFG_SECCOMP)) {
@@ -1144,21 +1202,6 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 		return 0;
 	}
 
-	// cgroup
-	if (strncmp(ptr, "cgroup ", 7) == 0) {
-		if (checkcfg(CFG_CGROUP)) {
-			cfg.cgroup = strdup(ptr + 7);
-			if (!cfg.cgroup)
-				errExit("strdup");
-
-			check_cgroup_file(cfg.cgroup);
-			set_cgroup(cfg.cgroup, getpid());
-		}
-		else
-			warning_feature_disabled("cgroup");
-		return 0;
-	}
-
 	// writable-etc
 	if (strcmp(ptr, "writable-etc") == 0) {
 		if (cfg.etc_private_keep) {
@@ -1401,11 +1444,6 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 				fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
 				exit(1);
 			}
-			struct stat s;
-			if (stat("/proc/sys/kernel/grsecurity", &s) == 0) {
-				fprintf(stderr, "Error: --overlay option is not available on Grsecurity systems\n");
-				exit(1);
-			}
 			arg_overlay = 1;
 			arg_overlay_keep = 1;
 			arg_overlay_reuse = 1;
@@ -1438,11 +1476,6 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 				fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
 				exit(1);
 			}
-			struct stat s;
-			if (stat("/proc/sys/kernel/grsecurity", &s) == 0) {
-				fprintf(stderr, "Error: --overlay option is not available on Grsecurity systems\n");
-				exit(1);
-			}
 			arg_overlay = 1;
 		}
 		else
@@ -1459,11 +1492,6 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 				fprintf(stderr, "Error: --overlay and --chroot options are mutually exclusive\n");
 				exit(1);
 			}
-			struct stat s;
-			if (stat("/proc/sys/kernel/grsecurity", &s) == 0) {
-				fprintf(stderr, "Error: --overlay option is not available on Grsecurity systems\n");
-				exit(1);
-			}
 			arg_overlay = 1;
 			arg_overlay_keep = 1;
 
@@ -1576,9 +1604,6 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 			int r = name2pid(ptr + 14, &pid);
 			EUID_USER();
 			if (!r) {
-				if (!cfg.shell && !arg_shell_none)
-					cfg.shell = guess_shell();
-
 				// find first non-option arg
 				int i;
 				for (i = 1; i < cfg.original_argc && strncmp(cfg.original_argv[i], "--", 2) != 0; i++);
@@ -1977,4 +2002,10 @@ void profile_list_augment(char **list, const char *items)
 		errExit("asprintf");
 	free(*list);
 	*list = profile_list_compress(tmp);
+
+	// lists should not grow indefinitely
+	if (strlen(*list) > MAX_LIST) {
+		fprintf(stderr, "Error: argument list is too long\n");
+		exit(1);
+	}
 }
