@@ -164,7 +164,8 @@ void set_profile_run_file(pid_t pid, const char *fname) {
 	free(runfile);
 }
 
-int set_sandbox_run_file(pid_t pid, pid_t child) {
+static int sandbox_lock_fd = -1;
+void set_sandbox_run_file(pid_t pid, pid_t child) {
 	char *runfile;
 	if (asprintf(&runfile, "%s/%d", RUN_FIREJAIL_SANDBOX_DIR, pid) == -1)
 		errExit("asprintf");
@@ -193,14 +194,21 @@ int set_sandbox_run_file(pid_t pid, pid_t child) {
 
 	// set exclusive lock on the file
 	// the lock is never inherited, and is released if this process dies ungracefully
-	struct flock sandboxlock = {
+	struct flock sandbox_lock = {
 		.l_type = F_WRLCK,
 		.l_whence = SEEK_SET,
 		.l_start = 0,
 		.l_len = 0,
 	};
-	if (fcntl(fd, F_SETLK, &sandboxlock) < 0)
+	if (fcntl(fd, F_SETLK, &sandbox_lock) < 0)
 		errExit("fcntl");
 
-	return fd;
+	sandbox_lock_fd = fd;
+}
+
+void release_sandbox_lock(void) {
+	assert(sandbox_lock_fd > -1);
+
+	close(sandbox_lock_fd);
+	sandbox_lock_fd = -1;
 }
