@@ -50,7 +50,7 @@
 #include <sys/apparmor.h>
 #endif
 
-static int force_nonewprivs = 0;
+extern int just_run_the_shell;
 
 static int monitored_pid = 0;
 static void sandbox_handler(int sig){
@@ -127,10 +127,17 @@ static void set_caps(void) {
 }
 
 #ifdef HAVE_APPARMOR
-void set_apparmor(void) {
+static void set_apparmor(void) {
 	EUID_ASSERT();
 	if (checkcfg(CFG_APPARMOR) && arg_apparmor) {
-		if (aa_change_onexec("firejail-default")) {
+		int res = 0;
+		if(apparmor_replace){
+			fwarning("Replacing profile instead of stacking it. It is a legacy behavior that can result in relaxation of the protection. It is here as a temporary measure to unbreak the software that has been broken by switching to the stacking behavior.\n");
+			res = aa_change_onexec(apparmor_profile);
+		} else {
+			res = aa_stack_onexec(apparmor_profile);
+		}
+		if (res) {
 			fwarning("Cannot confine the application using AppArmor.\n"
 				"Maybe firejail-default AppArmor profile is not loaded into the kernel.\n"
 				"As root, run \"aa-enforce firejail-default\" to load it.\n");
@@ -485,6 +492,9 @@ static void close_file_descriptors(void) {
 
 void start_application(int no_sandbox, int fd, char *set_sandbox_status) {
 	if (no_sandbox == 0) {
+#ifdef HAVE_APPARMOR
+		set_apparmor();
+#endif
 		close_file_descriptors();
 
 		// set nice and rlimits
@@ -506,10 +516,28 @@ void start_application(int no_sandbox, int fd, char *set_sandbox_status) {
 		printf("LD_PRELOAD=%s\n", getenv("LD_PRELOAD"));
 	}
 
+	if (just_run_the_shell) {
+		char *arg[2];
+		arg[0] = cfg.usershell;
+		arg[1] = NULL;
+
+		if (!arg_command && !arg_quiet)
+			print_time();
+
+		__gcov_dump();
+
+		seccomp_install_filters();
+
+		if (set_sandbox_status)
+			*set_sandbox_status = SANDBOX_DONE;
+		execvp(arg[0], arg);
+
+
+	}
 	//****************************************
 	// start the program without using a shell
 	//****************************************
-	if (arg_shell_none) {
+	else if (!arg_appimage && !arg_doubledash) {
 		if (arg_debug) {
 			int i;
 			for (i = cfg.original_program_index; i < cfg.original_argc; i++) {
@@ -543,15 +571,14 @@ void start_application(int no_sandbox, int fd, char *set_sandbox_status) {
 	//****************************************
 	// start the program using a shell
 	//****************************************
-	else {
-		assert(cfg.shell);
-
+	else { // appimage or double-dash
 		char *arg[5];
 		int index = 0;
-		arg[index++] = cfg.shell;
+		assert(cfg.usershell);
+		arg[index++] = cfg.usershell;
 		if (cfg.command_line) {
 			if (arg_debug)
-				printf("Running %s command through %s\n", cfg.command_line, cfg.shell);
+				printf("Running %s command through %s\n", cfg.command_line, cfg.usershell);
 			arg[index++] = "-c";
 			if (arg_doubledash)
 				arg[index++] = "--";
@@ -559,11 +586,11 @@ void start_application(int no_sandbox, int fd, char *set_sandbox_status) {
 		}
 		else if (login_shell) {
 			if (arg_debug)
-				printf("Starting %s login shell\n", cfg.shell);
+				printf("Starting %s login shell\n", cfg.usershell);
 			arg[index++] = "-l";
 		}
 		else if (arg_debug)
-			printf("Starting %s shell\n", cfg.shell);
+			printf("Starting %s shell\n", cfg.usershell);
 
 		assert(index < 5);
 		arg[index] = NULL;
@@ -571,7 +598,7 @@ void start_application(int no_sandbox, int fd, char *set_sandbox_status) {
 		if (arg_debug) {
 			char *msg;
 			if (asprintf(&msg, "sandbox %d, execvp into %s",
-				sandbox_pid, cfg.command_line ? cfg.command_line : cfg.shell) == -1)
+				sandbox_pid, cfg.command_line ? cfg.command_line : cfg.usershell) == -1)
 				errExit("asprintf");
 			logmsg(msg);
 			free(msg);
@@ -608,7 +635,6 @@ static void enforce_filters(void) {
 	fmessage("\n** Warning: dropping all Linux capabilities and setting NO_NEW_PRIVS prctl **\n\n");
 	// enforce NO_NEW_PRIVS
 	arg_nonewprivs = 1;
-	force_nonewprivs = 1;
 
 	// disable all capabilities
 	arg_caps_drop_all = 1;
@@ -811,14 +837,9 @@ int sandbox(void* sandbox_arg) {
 			exit(rv);
 	}
 
-#ifdef HAVE_FORCE_NONEWPRIVS
-	bool always_enforce_filters = true;
-#else
-	bool always_enforce_filters = false;
-#endif
 	// for --appimage, --chroot and --overlay* we force NO_NEW_PRIVS
 	// and drop all capabilities
-	if (getuid() != 0 && (arg_appimage || cfg.chrootdir || arg_overlay || always_enforce_filters))
+	if (getuid() != 0 && (arg_appimage || cfg.chrootdir || arg_overlay))
 		enforce_filters();
 
 	// need ld.so.preload if tracing or seccomp with any non-default lists
@@ -1113,8 +1134,10 @@ int sandbox(void* sandbox_arg) {
 			struct stat s;
 			if (stat(cfg.homedir, &s) == 0) {
 				/* coverity[toctou] */
-				if (chdir(cfg.homedir) < 0)
-					errExit("chdir");
+				if (chdir(cfg.homedir) < 0) {
+					fprintf(stderr, "Error: unable to enter home directory: %s: %s\n", cfg.homedir, strerror(errno));
+					exit(1);
+				}
 			}
 		}
 	}
@@ -1150,9 +1173,6 @@ int sandbox(void* sandbox_arg) {
 	// save cpu affinity mask to CPU_CFG file
 	save_cpu();
 
-	// save cgroup in CGROUP_CFG file
-	save_cgroup();
-
 	// set seccomp
 	// install protocol filter
 #ifdef SYS_socket
@@ -1194,6 +1214,16 @@ int sandbox(void* sandbox_arg) {
 		seccomp_load(RUN_SECCOMP_MDWX_32);
 	}
 
+	if (cfg.restrict_namespaces) {
+		seccomp_filter_namespaces(true, cfg.restrict_namespaces);
+		seccomp_filter_namespaces(false, cfg.restrict_namespaces);
+
+		if (arg_debug)
+			printf("Install namespaces filter\n");
+		seccomp_load(RUN_SECCOMP_NS);	// install filter
+		seccomp_load(RUN_SECCOMP_NS_32);
+	}
+
 	// make seccomp filters read-only
 	fs_remount(RUN_SECCOMP_DIR, MOUNT_READONLY, 0);
 	seccomp_debug();
@@ -1248,17 +1278,15 @@ int sandbox(void* sandbox_arg) {
 	//****************************************
 	// Set NO_NEW_PRIVS if desired
 	//****************************************
-	if (arg_nonewprivs) {
-		prctl(PR_SET_NO_NEW_PRIVS, 1, 0, 0, 0);
-
-		if (prctl(PR_GET_NO_NEW_PRIVS, 0, 0, 0, 0) != 1) {
-			fwarning("cannot set NO_NEW_PRIVS, it requires a Linux kernel version 3.5 or newer.\n");
-			if (force_nonewprivs) {
-				fprintf(stderr, "Error: NO_NEW_PRIVS required for this sandbox, exiting ...\n");
-				exit(1);
-			}
+#ifndef HAVE_FORCE_NONEWPRIVS
+	if (arg_nonewprivs)
+#endif
+	{
+		if (prctl(PR_SET_NO_NEW_PRIVS, 1, 0, 0, 0) != 0) {
+			fprintf(stderr, "Error: cannot set NO_NEW_PRIVS, it requires a Linux kernel version 3.5 or newer.\n");
+			exit(1);
 		}
-		else if (arg_debug)
+		if (arg_debug)
 			printf("NO_NEW_PRIVS set\n");
 	}
 
@@ -1284,10 +1312,7 @@ int sandbox(void* sandbox_arg) {
 		errExit("fork");
 
 	if (app_pid == 0) {
-#ifdef HAVE_APPARMOR
-		set_apparmor();
-#endif
-		start_application(0, -1, set_sandbox_status);
+		start_application(0, -1, set_sandbox_status);	// this function does not return
 	}
 
 	munmap(set_sandbox_status, 1);
