@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2021 Firejail Authors
+ * Copyright (C) 2014-2022 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -23,6 +23,7 @@
 #include <unistd.h>
 #include <net/if.h>
 #include <stdarg.h>
+#include <sys/resource.h>
 #include <sys/wait.h>
 #include "../include/seccomp.h"
 
@@ -72,11 +73,8 @@ static int __attribute__((noreturn)) sbox_do_exec_v(unsigned filtermask, char *
 	}
 
 	// close all other file descriptors
-	if ((filtermask & SBOX_KEEP_FDS) == 0) {
-		int i;
-		for (i = 3; i < FIREJAIL_MAX_FD; i++)
-			close(i); // close open files
-	}
+	if ((filtermask & SBOX_KEEP_FDS) == 0)
+		close_all(NULL, 0);
 
 	umask(027);
 
@@ -206,6 +204,11 @@ static int __attribute__((noreturn)) sbox_do_exec_v(unsigned filtermask, char *
 	if (filtermask & SBOX_USER)
 		drop_privs(1);
 	else if (filtermask & SBOX_ROOT) {
+		// https://seclists.org/oss-sec/2021/q4/43
+		struct rlimit tozero = { .rlim_cur = 0, .rlim_max = 0 };
+		if (setrlimit(RLIMIT_CORE, &tozero))
+			errExit("setrlimit");
+
 		// elevate privileges in order to get grsecurity working
 		if (setreuid(0, 0))
 			errExit("setreuid");
@@ -292,7 +295,8 @@ int sbox_run_v(unsigned filtermask, char * const arg[]) {
 	if (waitpid(child, &status, 0) == -1 ) {
 		errExit("waitpid");
 	}
-	if (WIFEXITED(status) && WEXITSTATUS(status) != 0) {
+	if (WIFSIGNALED(status) ||
+	   (WIFEXITED(status) && WEXITSTATUS(status) != 0)) {
 		fprintf(stderr, "Error: failed to run %s, exiting...\n", arg[0]);
 		exit(1);
 	}
