@@ -71,11 +71,17 @@ int seccomp_install_filters(void) {
 			assert(fl->fname);
 			if (arg_debug)
 				printf("Installing %s seccomp filter\n", fl->fname);
+			int rv = 0;
 #ifdef SECCOMP_FILTER_FLAG_LOG
-			if (syscall(SYS_seccomp, SECCOMP_SET_MODE_FILTER, SECCOMP_FILTER_FLAG_LOG, &fl->prog)) {
+			if (checkcfg(CFG_SECCOMP_LOG))
+				rv = syscall(SYS_seccomp, SECCOMP_SET_MODE_FILTER, SECCOMP_FILTER_FLAG_LOG, &fl->prog);
+			else
+				rv = prctl(PR_SET_SECCOMP, SECCOMP_MODE_FILTER, &fl->prog);
 #else
-			if (prctl(PR_SET_SECCOMP, SECCOMP_MODE_FILTER, &fl->prog)) {
+			rv = prctl(PR_SET_SECCOMP, SECCOMP_MODE_FILTER, &fl->prog);
 #endif
+
+			if (rv == -1) {
 				if (!err_printed)
 					fwarning("seccomp disabled, it requires a Linux kernel version 3.5 or newer.\n");
 				err_printed = 1;
@@ -410,7 +416,7 @@ int seccomp_filter_mdwx(bool native) {
 
 	// build the seccomp filter as a regular user
 	int rv = sbox_run(SBOX_USER | SBOX_CAPS_NONE | SBOX_SECCOMP, 3,
-		 PATH_FSECCOMP, command, filter);
+		PATH_FSECCOMP, command, filter);
 
 	if (rv) {
 		fprintf(stderr, "Error: cannot build memory-deny-write-execute filter\n");
@@ -423,6 +429,35 @@ int seccomp_filter_mdwx(bool native) {
 	return 0;
 }
 
+// create namespaces filter
+int seccomp_filter_namespaces(bool native, const char *list) {
+	if (arg_debug)
+		printf("Build restrict-namespaces filter\n");
+
+	const char *command, *filter;
+	if (native) {
+		command = "restrict-namespaces";
+		filter = RUN_SECCOMP_NS;
+	} else {
+		command = "restrict-namespaces.32";
+		filter = RUN_SECCOMP_NS_32;
+	}
+
+	// build the seccomp filter as a regular user
+	int rv = sbox_run(SBOX_USER | SBOX_CAPS_NONE | SBOX_SECCOMP, 4,
+		PATH_FSECCOMP, command, filter, list);
+
+	if (rv) {
+		fprintf(stderr, "Error: cannot build restrict-namespaces filter\n");
+		exit(rv);
+	}
+
+	if (arg_debug)
+		printf("restrict-namespaces filter configured\n");
+
+	return 0;
+}
+
 void seccomp_print_filter(pid_t pid) {
 	EUID_ASSERT();
 
