@@ -30,7 +30,9 @@ static char *usage_str =
 	"    -- - signal the end of options and disables further option processing.\n"
 	"    --allow-debuggers - allow tools such as strace and gdb inside the sandbox.\n"
 	"    --allusers - all user home directories are visible inside the sandbox.\n"
-	"    --apparmor - enable AppArmor confinement.\n"
+	"    --apparmor - enable AppArmor confinement with the default profile.\n"
+	"    --apparmor=profile_name - enable AppArmor confinement with a\n"
+	"\tcustom profile.\n"
 	"    --apparmor.print=name|pid - print apparmor status.\n"
 	"    --appimage - sandbox an AppImage application.\n"
 #ifdef HAVE_NETWORK
@@ -49,7 +51,6 @@ static char *usage_str =
 #ifdef HAVE_FILE_TRANSFER
 	"    --cat=name|pid filename - print content of file from sandbox container.\n"
 #endif
-	"    --cgroup=tasks-file - place the sandbox in the specified control group.\n"
 #ifdef HAVE_CHROOT
 	"    --chroot=dirname - chroot into directory.\n"
 #endif
@@ -90,6 +91,9 @@ static char *usage_str =
 	"    --deterministic-shutdown - terminate orphan processes.\n"
 	"    --dns=address - set DNS server.\n"
 	"    --dns.print=name|pid - print DNS configuration.\n"
+#ifdef HAVE_NETWORK
+	"    --dnstrace - monitor DNS queries.\n"
+#endif
 	"    --env=name=value - set environment variable.\n"
 	"    --fs.print=name|pid - print the filesystem log.\n"
 #ifdef HAVE_FILE_TRANSFER
@@ -98,6 +102,9 @@ static char *usage_str =
 	"    --help, -? - this help screen.\n"
 	"    --hostname=name - set sandbox hostname.\n"
 	"    --hosts-file=file - use file as /etc/hosts.\n"
+#ifdef HAVE_NETWORK
+	"    --icmptrace - monitor Server Name Indiication (TLS/SNI).\n"
+#endif
 	"    --ids-check - verify file system.\n"
 	"    --ids-init - initialize IDS database.\n"
 	"    --ignore=command - ignore command in profile files.\n"
@@ -152,7 +159,7 @@ static char *usage_str =
 	"\tparent interfaces.\n"
 	"    --netns=name - Run the program in a named, persistent network namespace.\n"
 	"    --netstats - monitor network statistics.\n"
-	"    --nettrace - monitor TCP and UDP traffic coming into the sandbox.\n"
+	"    --nettrace - monitor received TCP, UDP and ICMP traffic.\n"
 #endif
 	"    --nice=value - set nice value.\n"
 	"    --no3d - disable 3D hardware acceleration.\n"
@@ -205,7 +212,6 @@ static char *usage_str =
 	"    --private-srv=file,directory - build a new /srv in a temporary filesystem.\n"
 	"    --profile=filename|profile_name - use a custom profile.\n"
 	"    --profile.print=name|pid - print the name of profile file.\n"
-	"    --profile-path=directory - use this directory to look for profile files.\n"
 	"    --protocol=protocol,protocol,protocol - enable protocol filter.\n"
 	"    --protocol.print=name|pid - print the protocol filter.\n"
 #ifdef HAVE_FILE_TRANSFER
@@ -215,6 +221,9 @@ static char *usage_str =
 	"    --quiet - turn off Firejail's output.\n"
 	"    --read-only=filename - set directory or file read-only.\n"
 	"    --read-write=filename - set directory or file read-write.\n"
+	"    --restrict-namespaces - seccomp filter that blocks attempts to create new namespaces.\n"
+	"    --restrict-namespaces=namespace,namespace - seccomp filter that blocks attempts\n"
+	"\tto create specified namespaces.\n"
 	"    --rlimit-as=number - set the maximum size of the process's virtual memory.\n"
 	"\t(address space) in bytes.\n"
 	"    --rlimit-cpu=number - set the maximum CPU time in seconds.\n"
@@ -243,8 +252,6 @@ static char *usage_str =
 	"    --seccomp.32[.drop,.keep][=syscall] - like above but for 32 bit architecture.\n"
 	"    --seccomp-error-action=errno|kill|log - change error code, kill process\n"
 	"\tor log the attempt.\n"
-	"    --shell=none - run the program directly without a user shell.\n"
-	"    --shell=program - set default user shell.\n"
 	"    --shutdown=name|pid - shutdown the sandbox identified by name or PID.\n"
 	"    --tab - enable shell tab completion in sandboxes using private or\n"
 	"\twhitelisted home directories.\n"
