@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2021 Firejail Authors
+ * Copyright (C) 2014-2022 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -47,7 +47,7 @@ static char *get_user_name(uid_t uid) {
 
 static char *get_header(void) {
 	char *rv;
-	if (asprintf(&rv, "%-5.5s %-9.9s %-10.10s %-10.10s %s",
+	if (asprintf(&rv, "%-7.7s %-9.9s %-10.10s %-10.10s %s",
 		"PID", "User", "RX(KB/s)", "TX(KB/s)", "Command") == -1)
 		errExit("asprintf");
 
@@ -106,10 +106,8 @@ void get_stats(int parent) {
 	}
 
 	// store data
-	pids[parent].rx_delta = rx - pids[parent].rx;
-	pids[parent].rx = rx;
-	pids[parent].tx_delta = tx - pids[parent].tx;
-	pids[parent].tx = tx;
+	pids[parent].option.netstats.rx = rx - pids[parent].option.netstats.rx;
+	pids[parent].option.netstats.tx = tx - pids[parent].option.netstats.tx;
 
 
 	free(fname);
@@ -117,10 +115,8 @@ void get_stats(int parent) {
 	return;
 
 errexit:
-	pids[parent].rx = 0;
-	pids[parent].tx = 0;
-	pids[parent].rx_delta = 0;
-	pids[parent].tx_delta = 0;
+	pids[parent].option.netstats.rx = 0;
+	pids[parent].option.netstats.tx = 0;
 }
 
 
@@ -174,16 +170,16 @@ static void print_proc(int index, int itv, int col) {
 		ptruser = "";
 
 
-	float rx_kbps = ((float) pids[index].rx_delta / 1000) / itv;
+	float rx_kbps = ((float) pids[index].option.netstats.rx / 1000) / itv;
 	char ptrrx[15];
 	sprintf(ptrrx, "%.03f", rx_kbps);
 
-	float tx_kbps = ((float) pids[index].tx_delta / 1000) / itv;
+	float tx_kbps = ((float) pids[index].option.netstats.tx / 1000) / itv;
 	char ptrtx[15];
 	sprintf(ptrtx, "%.03f", tx_kbps);
 
 	char buf[1024 + 1];
-	snprintf(buf, 1024, "%-5.5s %-9.9s %-10.10s %-10.10s %s",
+	snprintf(buf, 1024, "%-7.7s %-9.9s %-10.10s %-10.10s %s",
 		pidstr, ptruser, ptrrx, ptrtx, ptrcmd);
 	if (col < 1024)
 		buf[col] = '\0';
@@ -205,7 +201,7 @@ void netstats(void) {
 	while (1) {
 		// set pid table
 		int i;
-		int itv = 1; 	// 1 second  interval
+		int itv = 3; 	// 3 second interval
 		pid_read(0);
 
 		// start rx/tx measurements
