@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2021 Firejail Authors
+ * Copyright (C) 2014-2022 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -73,6 +73,25 @@ static inline int atoip(const char *str, uint32_t *ip) {
 	return 0;
 }
 
+// read an IPv4 address in CIDR format, for example 192.168.1.0/24
+static inline int atocidr(const char *str, uint32_t *ip, uint32_t *mask) {
+	unsigned a, b, c, d, e;
+
+	// extract ip
+	int rv = sscanf(str, "%u.%u.%u.%u/%u", &a, &b, &c, &d, &e);
+	if (rv != 5 || a > 255 || b > 255 || c > 255 || d > 255 || e > 32)
+		return 1;
+	*ip = a * 0x1000000 + b * 0x10000 + c * 0x100 + d;
+
+	// extract mask
+	uint32_t tmp;
+	unsigned i;
+	for (i = 0, *mask = 0, tmp = 0x80000000; i < e; i++, tmp >>= 1) {
+		*mask |= tmp;
+	}
+	return 0;
+}
+
 // verify an ip address is in the network range given by ifip and mask
 static inline char *in_netrange(uint32_t ip, uint32_t ifip, uint32_t ifmask) {
 	if ((ip & ifmask) != (ifip & ifmask))
@@ -115,12 +134,19 @@ static inline int mac_not_zero(const unsigned char mac[6]) {
 
 void timetrace_start(void);
 float timetrace_end(void);
-int join_namespace(pid_t pid, char *type);
+int join_namespace_by_fd(int dirfd, char *typestr);
+int join_namespace(pid_t pid, char *typestr);
 int name2pid(const char *name, pid_t *pid);
 char *pid_proc_comm(const pid_t pid);
 char *pid_proc_cmdline(const pid_t pid);
 int pid_proc_cmdline_x11_xpra_xephyr(const pid_t pid);
 int pid_hidepid(void);
+char *do_replace_cntrl_chars(char *str, char c);
+char *replace_cntrl_chars(const char *str, char c);
+int has_cntrl_chars(const char *str);
+void reject_cntrl_chars(const char *fname);
+void reject_meta_chars(const char *fname, int globbing);
 void warn_dumpable(void);
 const char *gnu_basename(const char *path);
+int *str_to_int_array(const char *str, size_t *sz);
 #endif
