@@ -7,8 +7,7 @@ export MALLOC_CHECK_=3
 export MALLOC_PERTURB_=$(($RANDOM % 255 + 1))
 export LC_ALL=C
 
-which firefox 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v firefox
 then
 	echo "TESTING: firefox x11 xorg"
 	./firefox.exp
@@ -16,8 +15,7 @@ else
 	echo "TESTING SKIP: firefox not found"
 fi
 
-which transmission-gtk 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v transmission-gtk
 then
 	echo "TESTING: transmission-gtk x11 xorg"
 	./transmission-gtk.exp
@@ -25,8 +23,7 @@ else
 	echo "TESTING SKIP: transmission-gtk not found"
 fi
 
-which transmission-qt 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v transmission-qt
 then
 	echo "TESTING: transmission-qt x11 xorg"
 	./transmission-qt.exp
@@ -34,8 +31,7 @@ else
 	echo "TESTING SKIP: transmission-qt not found"
 fi
 
-which thunderbird 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v thunderbird
 then
 	echo "TESTING: thunderbird x11 xorg"
 	./thunderbird.exp
