@@ -10,49 +10,42 @@ export LC_ALL=C
 echo "TESTING: no x11 (test/apps-x11/x11-none.exp)"
 ./x11-none.exp
 
-
-which xterm 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v xterm
 then
 	echo "TESTING: xterm x11 xorg"
 	./xterm-xorg.exp
 
-	which xpra 2>/dev/null
-	if [ "$?" -eq 0 ];
+	if command -v xpra
 	then
-	echo "TESTING: xterm x11 xpra"
-	./xterm-xpra.exp
+		echo "TESTING: xterm x11 xpra"
+		./xterm-xpra.exp
 	fi
 
-	which Xephyr 2>/dev/null
-	if [ "$?" -eq 0 ];
+	if command -v Xephyr
 	then
-	echo "TESTING: xterm x11 xephyr"
-	./xterm-xephyr.exp
+		echo "TESTING: xterm x11 xephyr"
+		./xterm-xephyr.exp
 	fi
 else
 	echo "TESTING SKIP: xterm not found"
 fi
 
 # check xpra/xephyr
-which xpra 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v xpra
 then
-        echo "xpra found"
+	echo "xpra found"
 else
-        echo "xpra not found"
-	which Xephyr 2>/dev/null
-	if [ "$?" -eq 0 ];
+	echo "xpra not found"
+	if command -v Xephyr
 	then
-        	echo "Xephyr found"
+		echo "Xephyr found"
 	else
-        	echo "TESTING SKIP: xpra and/or Xephyr not found"
+		echo "TESTING SKIP: xpra and/or Xephyr not found"
 		exit
 	fi
 fi
 
-which firefox 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v firefox
 then
 	echo "TESTING: firefox x11"
 	./firefox.exp
@@ -60,8 +53,7 @@ else
 	echo "TESTING SKIP: firefox not found"
 fi
 
-which chromium 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v chromium
 then
 	echo "TESTING: chromium x11"
 	./chromium.exp
@@ -69,8 +61,7 @@ else
 	echo "TESTING SKIP: chromium not found"
 fi
 
-which transmission-gtk 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v transmission-gtk
 then
 	echo "TESTING: transmission-gtk x11"
 	./transmission-gtk.exp
@@ -78,8 +69,7 @@ else
 	echo "TESTING SKIP: transmission-gtk not found"
 fi
 
-which thunderbird 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v thunderbird
 then
 	echo "TESTING: thunderbird x11"
 	./thunderbird.exp
