@@ -7,12 +7,10 @@ export MALLOC_CHECK_=3
 export MALLOC_PERTURB_=$(($RANDOM % 255 + 1))
 export LC_ALL=C
 
-LIST="firefox midori chromium opera transmission-qt qbittorrent uget-gtk filezilla gthumb thunderbird "
-LIST+="vlc fbreader deluge gnome-mplayer xchat wine kcalc ktorrent hexchat"
+apps=(firefox midori chromium opera transmission-qt qbittorrent uget-gtk filezilla gthumb thunderbird vlc fbreader deluge gnome-mplayer xchat wine kcalc ktorrent hexchat)
 
-for app in $LIST; do
-	which $app 2>/dev/null
-	if [ "$?" -eq 0 ];
+for app in "${apps[@]}"; do
+	if command -v "$app"
 	then
 		echo "TESTING: $app"
 		./$app.exp
