@@ -5,8 +5,8 @@
 
 i="0"
 
-while  [ $i -lt 150000 ]
+while [[ $i -lt 150000 ]]
 do
-	echo message number $i
-	i=$[$i+1]
+	echo "message number $i"
+	i=$((i+1))
 done
