@@ -11,8 +11,7 @@ export LC_ALL=C
 #********************************
 # firecfg
 #********************************
-which less 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v less
 then
 	echo "TESTING: firecfg (test/root/firecfg.exp)"
 	mv /home/netblue/.local/share/applications /home/netblue/.local/share/applications-store
@@ -25,24 +24,24 @@ fi
 #********************************
 # servers
 #********************************
-if [ -f /etc/init.d/snmpd ]
+if [[ -f /etc/init.d/snmpd ]]
 then
 	echo "TESTING: snmpd (test/root/snmpd.exp)"
 	./snmpd.exp
 else
-	echo "TESTING SKIP: snmpd  not found"
+	echo "TESTING SKIP: snmpd not found"
 fi
 
 
-if [ -f /etc/init.d/apache2 ]
+if [[ -f /etc/init.d/apache2 ]]
 then
 	echo "TESTING: apache2 (test/root/apache2.exp)"
 	./apache2.exp
 else
-	echo "TESTING SKIP: apache2  not found"
+	echo "TESTING SKIP: apache2 not found"
 fi
 
-if [ -f /etc/init.d/isc-dhcp-server ]
+if [[ -f /etc/init.d/isc-dhcp-server ]]
 then
 	echo "TESTING: isc dhcp server (test/root/isc-dhscp.exp)"
 	./isc-dhcp.exp
@@ -50,20 +49,20 @@ else
 	echo "TESTING SKIP: isc dhcp server not found"
 fi
 
-if [ -f /etc/init.d/unbound ]
+if [[ -f /etc/init.d/unbound ]]
 then
 	echo "TESTING: unbound (test/root/unbound.exp)"
 	./unbound.exp
 else
-	echo "TESTING SKIP: unbound  not found"
+	echo "TESTING SKIP: unbound not found"
 fi
 
-if [ -f /etc/init.d/nginx ]
+if [[ -f /etc/init.d/nginx ]]
 then
 	echo "TESTING: nginx (test/root/nginx.exp)"
 	./nginx.exp
 else
-	echo "TESTING SKIP: nginx  not found"
+	echo "TESTING SKIP: nginx not found"
 fi
 
 #********************************
@@ -103,9 +102,6 @@ echo "TESTING: firejail configuration (test/root/checkcfg.exp)"
 ./checkcfg.exp
 cp ../../etc/firejail.config /etc/firejail/.
 
-echo "TESTING: cgroup (test/root/cgroup.exp)"
-./cgroup.exp
-
 echo "TESTING: tmpfs (test/root/option_tmpfs.exp)"
 ./option_tmpfs.exp
 
