@@ -7,8 +7,7 @@ export MALLOC_CHECK_=3
 export MALLOC_PERTURB_=$(($RANDOM % 255 + 1))
 export LC_ALL=C
 
-which cpio 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v cpio
 then
 	echo "TESTING: cpio"
 	./cpio.exp
@@ -16,8 +15,7 @@ else
 	echo "TESTING SKIP: cpio not found"
 fi
 
-#which strings
-#if [ "$?" -eq 0 ];
+#if command -v strings
 #then
 #	echo "TESTING: strings"
 #	./strings.exp
@@ -25,8 +23,7 @@ fi
 #	echo "TESTING SKIP: strings not found"
 #fi
 
-which gzip 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v gzip
 then
 	echo "TESTING: gzip"
 	./gzip.exp
@@ -34,8 +31,7 @@ else
 	echo "TESTING SKIP: gzip not found"
 fi
 
-which xzdec 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v xzdec
 then
 	echo "TESTING: xzdec"
 	./xzdec.exp
@@ -43,8 +39,7 @@ else
 	echo "TESTING SKIP: xzdec not found"
 fi
 
-which xz 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v xz
 then
 	echo "TESTING: xz"
 	./xz.exp
@@ -52,8 +47,7 @@ else
 	echo "TESTING SKIP: xz not found"
 fi
 
-which less 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v less
 then
 	echo "TESTING: less"
 	./less.exp
@@ -61,8 +55,7 @@ else
 	echo "TESTING SKIP: less not found"
 fi
 
-which file 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v file
 then
 	echo "TESTING: file"
 	./file.exp
@@ -70,8 +63,7 @@ else
 	echo "TESTING SKIP: file not found"
 fi
 
-which tar 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v tar
 then
 	echo "TESTING: tar"
 	./tar.exp
@@ -79,8 +71,7 @@ else
 	echo "TESTING SKIP: tar not found"
 fi
 
-which ping 2>/dev/null
-if [ "$?" -eq 0 ];
+if command -v ping
 then
 	echo "TESTING: ping"
 	./ping.exp
